import { Icons } from "@/components/icons";
import { Button } from "@/components/ui/button";
import { useSession } from "next-auth/react";
import { useRegweet } from "../../hooks/use-regweet";
import { IGweet } from "../../types";

export const RegweetButton = ({ gweet }: { gweet: IGweet }) => {
  const { data: session } = useSession();
  const hasRegweeted = gweet.regweets.some(
    (regweet) => regweet.userId === session?.user?.id,
  );

  const mutation = useRegweet();

  return (
    <div className="relative inline-flex items-center">
      <Button
        onClick={(e) => {
          e.stopPropagation();
          if (session) {
            mutation.mutate({
              gweetId: gweet.id,
              userId: session.user.id,
            });
          }
        }}
        variant="ghost" size="icon" className="hover:bg-green-800 z-40"
      >
        {hasRegweeted ?
          <Icons.regweet className="w-6 h-6 text-green-600" />
          : <Icons.regweet className="w-6 h-6" />
        }
      </Button>

      {gweet.regweets.length > 0 && (
        <span className="absolute pl-12">{gweet.regweets.length}</span>
      )}
    </div>
  );
};